# -*- coding: utf-8 -*-

from ....Methods.Slot.Slot import SlotCheckError


class Slot53InterError(SlotCheckError):
    """ """

    pass


class S53_NoneError(SlotCheckError):
    """Raised when a propery of HoleM53 is None"""

    pass


class S53_Rext0CheckError(SlotCheckError):
    """ """

    pass


class S53_Rext1CheckError(SlotCheckError):
    """ """

    pass


class S53_W4CheckError(SlotCheckError):
    """ """

    pass


class S53_W5CheckError(SlotCheckError):
    """ """

    pass
